const letters = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
const numbers = "1234567890";
const buttonsContainer = document.getElementById('buttons');
const screen = document.getElementById('screen');
let currentWord = "";
let letterVoiceEnabled = true;

function addLetter(letter) {
    currentWord += letter;
    screen.textContent = currentWord;
    speakLetter(letter);
}

function addSpace() {
    currentWord += ' ';
    screen.textContent = currentWord;
}

function clearWord() {
    currentWord = "";
    screen.textContent = "Type a word...";
}

function speakLetter(letter) {
    if (letterVoiceEnabled) {
        const synth = window.speechSynthesis;
        const utterThis = new SpeechSynthesisUtterance(letter);
        synth.speak(utterThis);
    }
}

function speakWord() {
    if (currentWord.trim() !== "") {
        const synth = window.speechSynthesis;
        const utterThis = new SpeechSynthesisUtterance(currentWord);
        synth.speak(utterThis);
    } else {
        alert("Please enter a word.");
    }
}

function deleteLastLetter() {
    currentWord = currentWord.slice(0, -1);
    screen.textContent = currentWord;
}

function turnOffLetterVoice() {
    letterVoiceEnabled = false;
}

function turnOnLetterVoice() {
    letterVoiceEnabled = true;
}

// Add buttons for letters
letters.split('').forEach(letter => {
    addButton(letter);
});

// Add buttons for numbers
numbers.split('').forEach(number => {
    addButton(number);
});

// Add space button
addButton(' ', addSpace, 'Space');

// Add backspace button
addButton('←', deleteLastLetter, 'Backspace');

// Additional styling modifications
document.querySelector('.speak-n-spell').style.width = '60%'; // Adjust the width of the app
document.querySelectorAll('.buttons button').forEach(button => {
    button.style.width = '60px'; // Increase button width
    button.style.height = '60px'; // Increase button height
});

// Modify SPEAK button style
const speakButton = document.querySelector('.control-buttons button:first-child');
speakButton.style.backgroundColor = '#87CEEB'; // Light blue color
speakButton.style.width = '100px'; // Larger width
speakButton.style.fontWeight = 'bold'; // Bold font

// Modify CLEAR button style
const clearButton = document.querySelector('.control-buttons button:last-child');
clearButton.style.backgroundColor = 'red'; // Red color
clearButton.style.width = '100px'; // Larger width
clearButton.style.fontWeight = 'bold'; // Bold font
clearButton.style.border = '1px solid black'; // Thin black border

function addButton(label, onclick, className = '') {
    const button = document.createElement('button');
    button.textContent = label === ' ' ? 'Space' : label; // Display "Space" on the button
    button.onclick = onclick ? onclick : () => addLetter(label);
    if (className) {
        button.classList.add(className);
    }
    buttonsContainer.appendChild(button);
}

